import { FS, Path } from "./deps.ts";

const STORAGE_ROOT = Path.resolve("./data/files");



export function walkFiles(path: string) {
   const norm = Path.normalize(path);
   const p = Path.join(STORAGE_ROOT, norm);

   const walker = FS.walk(p, { includeFiles: true, includeDirs: false })

   // Make path of entry relative to the root and return an async iterator
   return (async function* () {
      for await (const entry of walker) {
         const rel = Path.relative(STORAGE_ROOT, entry.path);
         yield { ...entry, path: rel };
      }
   })();
}

export async function writeFile(path: string, content: Uint8Array) {
   const norm = Path.normalize(path);
   const p = Path.join(STORAGE_ROOT, norm);

   await FS.ensureFile(p);
   await Deno.writeFile(p, content);
}

export async function readFile(path: string) {
   const norm = Path.normalize(path);
   const p = Path.join(STORAGE_ROOT, norm);

   if (!await FS.exists(p)) return undefined;

   const s = await Deno.stat(p);
   if (!s.isFile) return undefined;

   return await Deno.readFile(p);
}